using System;
using System.Collections;
using System.ComponentModel;
using System.Data;


namespace I51257
{
	/// <summary>
	/// Summary description for DataCollection.
	/// </summary>
	public class DataCollection : IList
	{
		private ArrayList list;

		public DataCollection()
		{
			list = new ArrayList();
		}

		public Data this[int index]
		{
			get
			{
				return (Data)list[index];
			}
			set
			{
				list[index] = value;
                RaisePropertyChanged(list[index].ToString());
			}
		}

        void RaisePropertyChanged(string name)
        {
            if (PropertyChanged != null)
                PropertyChanged(this, new PropertyChangedEventArgs(name));
        }

        public event PropertyChangedEventHandler PropertyChanged;

		#region IList Members

        public event System.ComponentModel.ListChangedEventHandler ListChanged;

		public bool IsReadOnly
		{
			get
			{
				return false;
			}
		}

		object IList.this[int index]
		{
			get
			{
				return list[index];
			}
			set
			{
				list[index] = value;
			}
		}

		public void RemoveAt(int index)
		{
            list.RemoveAt(index);
            RaiseListChanged(ListChangedType.ItemDeleted, index);
		}

		public void Insert(int index, object value)
		{
            list.Insert(index, value);
            RaiseListChanged(ListChangedType.ItemAdded, index);
		}

		public void Remove(object value)
		{
            int index = list.IndexOf(value);
			list.Remove(value);
            RaiseListChanged(ListChangedType.ItemDeleted, index);
		}

		public bool Contains(object value)
		{
			return list.Contains(value);
		}

		public void Clear()
		{
			list.Clear();
		}

		public int IndexOf(object value)
		{
			return list.IndexOf(value);
		}

		public int Add(object value)
		{
			int count = list.Add(value);
            RaiseListChanged(ListChangedType.ItemAdded, list.Count-1);
            return count;
		}

		public bool IsFixedSize
		{
			get
			{
				return false;
			}
		}

        void RaiseListChanged(ListChangedType type, int index)
        {
            if (ListChanged != null)
                ListChanged(this, new ListChangedEventArgs(type, index));
        }

		#endregion

        #region ICollection Members

        public bool IsSynchronized
        {
            get
            {
                return false;
            }
        }

        public int Count
        {
            get
            {
                return list.Count;
            }
        }

        public void CopyTo(Array array, int index)
        {
            list.CopyTo(array, index);
        }

        public object SyncRoot
        {
            get
            {
                return list.SyncRoot;
            }
        }

        #endregion

        #region IEnumerable Members

        public IEnumerator GetEnumerator()
        {
            return list.GetEnumerator();
        }

        #endregion
	}
}
